TokenController class

Constructors

TokenController()

Properties

authRespModel ↔ AuthRespModel?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAuthHeader(String clientID, String clientSecretKey) → String
getToken({required DGePayConfigs dGePayConfigs}) → Future<AuthRespModel?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited