CheckTnxRespModel class

Constructors

CheckTnxRespModel({num? statusCode, Data? data})
CheckTnxRespModel.fromJson(dynamic json)

Properties

data → Data?
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → num?
no setter

Methods

copyWith({num? statusCode, Data? data}) → CheckTnxRespModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited