DGePayPaymentReqModel class

Constructors

DGePayPaymentReqModel({required String? customerToken, required String? note, required double? amount, required String? uniqueTxnId, required String? dialCode, required String? phoneNumber, required DGePayConfigs dGePayConfigs})

Properties

amount double?
getter/setter pair
customerToken String?
getter/setter pair
dGePayConfigs DGePayConfigs
getter/setter pair
dialCode String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
note String?
getter/setter pair
phoneNumber String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uniqueTxnId String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited