DGePayPaymentRespModel class

Constructors

DGePayPaymentRespModel({bool? status, num? errorCode, String? message, String? dGePayOrderId})
DGePayPaymentRespModel.fromJson(dynamic json)

Properties

dGePayOrderId String?
no setter
errorCode num?
no setter
hashCode int
The hash code for this object.
no setterinherited
message String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status bool?
no setter

Methods

copyWith({bool? status, num? errorCode, String? message, String? dGePayOrderId}) DGePayPaymentRespModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited