Data class

Constructors

Data({String? webviewUrl, String? uniqueTxnId})
Data.fromJson(dynamic json)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uniqueTxnId String?
no setter
webviewUrl String?
no setter

Methods

copyWith({String? webviewUrl, String? uniqueTxnId}) Data
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited