PaymentRespModel class

Constructors

PaymentRespModel({num? code, String? message, String? status, num? statusCode, num? success, Data? data, List<String>? error})
PaymentRespModel.fromJson(dynamic json)

Properties

code → num?
no setter
data → Data?
no setter
error → List<String>?
no setter
hashCode → int
The hash code for this object.
no setterinherited
message → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
no setter
statusCode → num?
no setter
success → num?
no setter

Methods

copyWith({num? code, String? message, String? status, num? statusCode, num? success, Data? data, List<String>? error}) → PaymentRespModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited