Data class

Constructors

Data({String? accessToken, String? expiryTime})
Data.fromJson(dynamic json)

Properties

accessToken String?
no setter
expiryTime String?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? accessToken, String? expiryTime}) Data
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited