Data class
Constructors
Properties
- amount → num?
-
no setter
- createdDate → num?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
no setter
- paymentMethod → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → String?
-
no setter
- txnId → String?
-
no setter
- txnNumber → String?
-
no setter
- uniqueTxnId → String?
-
no setter
Methods
-
copyWith(
{String? message, String? txnId, String? statusCode, num? amount, num? createdDate, String? txnNumber, String? paymentMethod, String? uniqueTxnId}) → Data -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited