DGePayConfigs class
Constructors
- DGePayConfigs({required String clientID, required String clientSecretKey, required String clientAPIKey, required String env})
Properties
- clientAPIKey → String
-
final
- clientID → String
-
final
- clientSecretKey → String
-
final
- env → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited