DGePayStatusRespModel class

Constructors

DGePayStatusRespModel({bool? status, num? errorCode, num? amount, String? message, String? dGePayOrderId})
DGePayStatusRespModel.fromJson(dynamic json)

Properties

amount num?
no setter
dGePayOrderId String?
no setter
errorCode num?
no setter
hashCode int
The hash code for this object.
no setterinherited
message String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status bool?
no setter

Methods

copyWith({bool? status, num? errorCode, num? amount, String? message, String? dGePayOrderId}) DGePayStatusRespModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited