PayeeInfo class

Constructors

PayeeInfo({String? dialCode, String? phoneNumber})
PayeeInfo.fromJson(dynamic json)

Properties

dialCode String?
no setter
hashCode int
The hash code for this object.
no setterinherited
phoneNumber String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? dialCode, String? phoneNumber}) PayeeInfo
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited