PaymentReqModel class
Constructors
- PaymentReqModel({String? customerToken, String? note, num? amount, String? paymentMethod, String? uniqueTxnId, PayeeInfo? payeeInfo, String? redirectUrl})
- PaymentReqModel.fromJson(dynamic json)
Properties
- amount → num?
-
no setter
- customerToken → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- note → String?
-
no setter
- payeeInfo → PayeeInfo?
-
no setter
- paymentMethod → String?
-
no setter
- redirectUrl → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uniqueTxnId → String?
-
no setter
Methods
-
copyWith(
{String? customerToken, String? note, num? amount, String? paymentMethod, String? uniqueTxnId, PayeeInfo? payeeInfo, String? redirectUrl}) → PaymentReqModel -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited